@@ -66,7 +66,6 @@ enum  {
 
 enum  {
 	TAB_PUBLIC = 0,
-	TAB_TRUSTED,
 	TAB_PRIVATE,
 	TAB_PASSWORD,
 	TAB_NUM_TABS
@@ -79,17 +78,6 @@ static SeahorseObjectPredicate pred_public = {
 	SEAHORSE_LOCATION_LOCAL, 
 	SEAHORSE_USAGE_PUBLIC_KEY, 
 	0, 
-	SEAHORSE_FLAG_TRUSTED | SEAHORSE_FLAG_IS_VALID, 
-	NULL 
-};
-
-static SeahorseObjectPredicate pred_trusted = {
-	0, 
-	0, 
-	0, 
-	SEAHORSE_LOCATION_LOCAL, 
-	SEAHORSE_USAGE_PUBLIC_KEY, 
-	SEAHORSE_FLAG_TRUSTED | SEAHORSE_FLAG_IS_VALID, 
 	0, 
 	NULL
 };
@@ -272,17 +260,6 @@ on_tab_changed (GtkNotebook* notebook, void* unused, guint page_num, SeahorseKey
 	fire_selection_changed (self);
 }
 
-static void 
-on_help_show (GtkButton* button, SeahorseKeyManager* self) 
-{
-	g_return_if_fail (SEAHORSE_IS_KEY_MANAGER (self));
-	g_return_if_fail (GTK_IS_BUTTON (button));
-	seahorse_widget_show_help (SEAHORSE_WIDGET (self));
-}
-
-
-
-
 static void 
 on_view_selection_changed (GtkTreeSelection* selection, SeahorseKeyManager* self) 
 {
@@ -291,9 +268,9 @@ on_view_selection_changed (GtkTreeSelection* selection, SeahorseKeyManager* self
 	g_idle_add ((GSourceFunc)fire_selection_changed, self);
 }
 
-static void 
-on_row_activated (GtkTreeView* view, GtkTreePath* path, 
-                  GtkTreeViewColumn* column, SeahorseKeyManager* self) 
+G_MODULE_EXPORT void
+on_keymanager_row_activated (GtkTreeView* view, GtkTreePath* path, 
+                                  GtkTreeViewColumn* column, SeahorseKeyManager* self) 
 {
 	SeahorseObject* obj;
 
@@ -307,8 +284,8 @@ on_row_activated (GtkTreeView* view, GtkTreePath* path,
 		seahorse_viewer_show_properties (SEAHORSE_VIEWER (self), obj);
 }
 
-static gboolean 
-on_key_list_button_pressed (GtkTreeView* view, GdkEventButton* event, SeahorseKeyManager* self) 
+G_MODULE_EXPORT gboolean
+on_keymanager_key_list_button_pressed (GtkTreeView* view, GdkEventButton* event, SeahorseKeyManager* self) 
 {
 	g_return_val_if_fail (SEAHORSE_IS_KEY_MANAGER (self), FALSE);
 	g_return_val_if_fail (GTK_IS_TREE_VIEW (view), FALSE);
@@ -319,8 +296,8 @@ on_key_list_button_pressed (GtkTreeView* view, GdkEventButton* event, SeahorseKe
 	return FALSE;
 }
 
-static gboolean 
-on_key_list_popup_menu (GtkTreeView* view, SeahorseKeyManager* self) 
+G_MODULE_EXPORT gboolean
+on_keymanager_key_list_popup_menu (GtkTreeView* view, SeahorseKeyManager* self) 
 {
 	SeahorseObject* obj;
 
@@ -341,8 +318,8 @@ on_file_new (GtkAction* action, SeahorseKeyManager* self)
 	seahorse_generate_select_show (seahorse_viewer_get_window (SEAHORSE_VIEWER (self)));
 }
 
-static void 
-on_new_button_clicked (GtkButton* button, SeahorseKeyManager* self) 
+G_MODULE_EXPORT void 
+on_keymanager_new_button (GtkButton* button, SeahorseKeyManager* self) 
 {
 	g_return_if_fail (SEAHORSE_IS_KEY_MANAGER (self));
 	g_return_if_fail (GTK_IS_BUTTON (button));
@@ -377,9 +354,6 @@ initialize_tab (SeahorseKeyManager* self, const char* tabwidget, guint tabid, co
 	selection = gtk_tree_view_get_selection (view);
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 	g_signal_connect (selection, "changed", G_CALLBACK (on_view_selection_changed), self);
-	g_signal_connect (view, "row-activated", G_CALLBACK (on_row_activated), self);
-	g_signal_connect (view, "button-press-event", G_CALLBACK (on_key_list_button_pressed), self);
-	g_signal_connect (view, "popup-menu", G_CALLBACK (on_key_list_popup_menu), self);
 	gtk_widget_realize (GTK_WIDGET (view));
 
 	/* Add new key store and associate it */
@@ -526,8 +500,8 @@ on_key_import_file (GtkAction* action, SeahorseKeyManager* self)
 	import_prompt (self);
 }
 
-static void 
-on_import_button_clicked (GtkButton* button, SeahorseKeyManager* self) 
+G_MODULE_EXPORT void 
+on_keymanager_import_button (GtkButton* button, SeahorseKeyManager* self) 
 {
 	g_return_if_fail (SEAHORSE_IS_KEY_MANAGER (self));
 	g_return_if_fail (GTK_IS_BUTTON (button));
@@ -601,9 +575,13 @@ on_clipboard_received (GtkClipboard* board, const char* text, SeahorseKeyManager
 	g_return_if_fail (SEAHORSE_IS_KEY_MANAGER (self));
 	g_return_if_fail (GTK_IS_CLIPBOARD (board));
 	g_return_if_fail (text != NULL);
-	
-	if (text != NULL && g_utf8_strlen (text, -1) > 0)
-		import_text (self, text);
+
+    g_assert(self->pv->filter_entry);
+    if (gtk_widget_is_focus (self->pv->filter_entry) == TRUE)
+	    gtk_editable_paste_clipboard (GTK_EDITABLE (self->pv->filter_entry));
+    else	
+    	if (text != NULL && g_utf8_strlen (text, -1) > 0)
+    		import_text (self, text);
 }
 
 static void 
@@ -911,12 +889,10 @@ seahorse_key_manager_constructor (GType type, guint n_props, GObjectConstructPar
 	                         "delete-event", G_CALLBACK (on_delete_event), self, 0);
 	
 	/* first time signals */
-	g_signal_connect_object (seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "help-button"), 
-	                         "clicked", G_CALLBACK (on_help_show), self, 0);
 	g_signal_connect_object (seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "import-button"), 
-	                         "clicked", G_CALLBACK (on_import_button_clicked), self, 0);
+	                         "clicked", G_CALLBACK (on_keymanager_import_button), self, 0);
 	g_signal_connect_object (seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "new-button"), 
-	                         "clicked", G_CALLBACK (on_new_button_clicked), self, 0);
+	                         "clicked", G_CALLBACK (on_keymanager_new_button), self, 0);
 	
 	/* The notebook */
 	g_signal_connect_object (self->pv->notebook, "switch-page", G_CALLBACK (on_tab_changed), self, G_CONNECT_AFTER);
@@ -969,7 +945,6 @@ seahorse_key_manager_constructor (GType type, guint n_props, GObjectConstructPar
 	
 	/* Initialize the tabs, and associate them up */
 	initialize_tab (self, "pub-key-tab", TAB_PUBLIC, "pub-key-list", &pred_public);
-	initialize_tab (self, "trust-key-tab", TAB_TRUSTED, "trust-key-list", &pred_trusted);
 	initialize_tab (self, "sec-key-tab", TAB_PRIVATE, "sec-key-list", &pred_private);
 	pred_password.tag = SEAHORSE_GKR_TYPE;
 	initialize_tab (self, "password-tab", TAB_PASSWORD, "password-list", &pred_password);
